<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrl="http://netkernel.org/xrl" xmlns:nk="http://netkernel.org">
    <xsl:output method="xml"/>
    
    <xsl:param name="formState"/>
    <xsl:param name="validationState"/>
    <xsl:param name="errorState"/>

    <xsl:variable name="formStateExists" select="$formState/hds/*[1]"/>
    
    <xsl:template match="/modules">
    		<div title="Module Management Wizard" desc="Package modules for deployment">
				<p>	
				Please select the modules you want to package. Change deployment runlevel if required.  Build the package with "Export Package".
				</p>
				<xsl:if test="$formStateExists and ( $errorState or $validationState/validity/invalid[formID='error'] )">
				<div style="background: #ff6666; padding: 5px;">
					<xsl:if test="$errorState">
					<div> <xsl:value-of select="$errorState/error/id"/> :  <xsl:value-of select="$errorState/error/message"/> </div>
					</xsl:if>
					<xsl:if test="$validationState">
						<xsl:for-each select="$validationState/validity/invalid[formID='error']/message">
							<div><xsl:value-of select="."/></div>
						</xsl:for-each>
					</xsl:if>
				</div>
				</xsl:if>			
				<form action="" method="post">
				<table>
					<tr><td><b>Package Name*</b> </td>
						<td colspan="3">
						<input type="text" name="uri" style="width: 350px;">
							<xsl:if test="$formStateExists">
							<xsl:attribute name="value"><xsl:value-of select="$formState/hds/uri"/></xsl:attribute>
							</xsl:if>
						</input>
						<xsl:if test="$formStateExists and $validationState and $validationState/validity/invalid[formID='uri']">
							<span style="background: #ff6666;">
							<xsl:value-of select="$validationState/validity/invalid[formID='uri']/message"/>
							</span>
						</xsl:if>
						</td>
					</tr>
					<tr><td><b>Package Version*</b> </td>
						<td colspan="3">
							<input type="text" name="version">
								<xsl:if test="$formStateExists">
								<xsl:attribute name="value"><xsl:value-of select="$formState/hds/version"/></xsl:attribute>
								</xsl:if>
							</input>
							<xsl:if test="$formStateExists and $validationState and $validationState/validity/invalid[formID='version']">
								<span style="background: #ff6666;">
									<xsl:value-of select="$validationState/validity/invalid[formID='version']/message"/>
								</span>
							</xsl:if>
						</td>
					</tr>
					<tr><td><b>Package	Description</b> </td><td colspan="3">
						<textarea type="text" name="description" style="width: 350px; height: 50px;">
							<xsl:choose> 
								<xsl:when test="$formStateExists">
								<xsl:value-of select="$formState/hds/description"/>
								</xsl:when>
								<xsl:otherwise>Description...</xsl:otherwise>
							</xsl:choose>
						</textarea>
						</td>
						<td>
					<input type="submit" value="Export Package"/></td></tr>
					
				</table>
				<table cellspacing="0" padding="0" class="titleframe">
					<tr>
						<td colspan="2"><b>Module</b></td>
						<td><b>URI</b></td>
						<td><b>Version</b></td>
						<td><b>Select</b></td>
						<td><b>Runlevel</b></td>
					</tr>
					<xsl:apply-templates select="module[position()&gt; 1]">
						<xsl:sort select="name"/>
					</xsl:apply-templates>
					<tr><td colspan="5"><input type="submit" value="Export Package"/></td></tr>
				</table>
				</form>
            </div>
    </xsl:template>
	<xsl:template match="module">
		<xsl:param name="fulcrums"/>
		<xsl:variable name="class">
			<xsl:choose>
				<xsl:when test="position() mod 2 = 0">
					<xsl:text>evenrow</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>oddrow</xsl:text>
				</xsl:otherwise>  
			</xsl:choose>
		</xsl:variable>
		<tr class="{$class}">
			<td>
				<xsl:choose>
					<xsl:when test="icon">
						<img width="24" height="24" src="icon?icon={icon}&amp;space={spaces/space[1]/id}&amp;version={spaces/space[1]/version}"/>
					</xsl:when>
					<xsl:otherwise>
						<img width="24" height="24" src="/tools/packager/pub/module.png"/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td valign="middle">
				<a href="/tools/exploreRedirect/{spaces/space[1]/id}/{version}"><xsl:value-of select="name"/></a>
			</td>
			<td>
				<xsl:value-of select="spaces/space[1]/id"/>
			</td>
			<td><xsl:value-of select="version"/></td>
			<td>
				<input type="hidden" name="ref" value="{position()}|{spaces/space[1]/id}|{spaces/space[1]/version}|{source}"/>
				<input name="selected" type="checkbox" value="{position()}">
					<xsl:if test="$formStateExists">
						<xsl:if test="$formState/hds/selected[position()]=position()">
							<xsl:attribute name="checked">true</xsl:attribute>
						</xsl:if>
					</xsl:if>
				</input>
			</td>
			<td>
				<input type="text" name="runlevel{position()}" value="{runlevel}" style="width: 20px;">
					<xsl:if test="runlevel=1">
						<xsl:attribute name="disabled">true</xsl:attribute>
					</xsl:if>
				</input>
			</td>
		</tr>
	</xsl:template>
</xsl:stylesheet>
