<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrl="http://netkernel.org/xrl" xmlns:nk="http://netkernel.org">
  <xsl:output method="xml"/>

  <xsl:template match="/row">
  <xsl:variable name="vtrans" select="translate(VP, '.', ',')"/>
  <sql>
  		SELECT 
  			PACKAGES.NAME,
  			PACKAGE_VERSIONS.ID AS VID,
  			PACKAGE_VERSIONS.VERSION AS VARRAY,
  			PACKAGE_VERSIONS.VERSION[0] || '.' || PACKAGE_VERSIONS.VERSION[1] || '.' || PACKAGE_VERSIONS.VERSION[2] as VERSION,
  			PACKAGE_VERSIONS.INSTALLED,
  			<xsl:value-of select="EQUALITY"/> AS EQUALITY,
  			'<xsl:value-of select="VP"/>' AS VDEP
  		FROM
  			PACKAGES, PACKAGE_VERSIONS
  		WHERE
  			PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
  			AND
  			PACKAGES.NAME='<xsl:value-of select="NAME"/>'
  			AND
  			<xsl:choose>
  				<xsl:when test="EQUALITY=1">
  					PACKAGE_VERSIONS.VERSION &lt;  ( <xsl:value-of select="$vtrans"/> )
  					<!-- 1 depends, 2 suggests, 3 recommends, 4 confilcts, 5 replaces -->
		  			<xsl:choose>
		  				<xsl:when test="DEPTYPE &lt;= 3">
		  					AND
					  				PACKAGE_VERSIONS.INSTALLED=FALSE
		  					AND
		  						(
			  						SELECT PACKAGE_VERSIONS.ID
			  						FROM 
			  						PACKAGES, PACKAGE_VERSIONS
			  						WHERE
			  						PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
						  			AND
						  			PACKAGES.NAME='<xsl:value-of select="NAME"/>'
						  			AND
						  			PACKAGE_VERSIONS.VERSION &lt;  ( <xsl:value-of select="$vtrans"/> )
						  			AND
						  			PACKAGE_VERSIONS.INSTALLED=TRUE
					  			) IS NULL
		  				</xsl:when>
		  				<xsl:when test="DEPTYPE &gt; 3">
		  					AND
		  						PACKAGE_VERSIONS.INSTALLED=TRUE
		  				</xsl:when>
		  			</xsl:choose>
  				</xsl:when>
  				<xsl:when test="EQUALITY=2">
  					PACKAGE_VERSIONS.VERSION &lt;=  ( <xsl:value-of select="$vtrans"/> )
  					<!-- 1 depends, 2 suggests, 3 recommends, 4 confilcts, 5 replaces -->
		  			<xsl:choose>
		  				<xsl:when test="DEPTYPE &lt;= 3">
		  					AND
					  				PACKAGE_VERSIONS.INSTALLED=FALSE
		  					AND
		  						(
			  						SELECT PACKAGE_VERSIONS.ID
			  						FROM 
			  						PACKAGES, PACKAGE_VERSIONS
			  						WHERE
			  						PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
						  			AND
						  			PACKAGES.NAME='<xsl:value-of select="NAME"/>'
						  			AND
						  			PACKAGE_VERSIONS.VERSION &lt;=  ( <xsl:value-of select="$vtrans"/> )
						  			AND
						  			PACKAGE_VERSIONS.INSTALLED=TRUE
					  			) IS NULL
		  				</xsl:when>
		  				<xsl:when test="DEPTYPE &gt; 3">
		  					AND
		  						PACKAGE_VERSIONS.INSTALLED=TRUE
		  				</xsl:when>
		  			</xsl:choose>
  				</xsl:when>
  				<xsl:when test="EQUALITY=3">
  					PACKAGE_VERSIONS.VERSION = ( <xsl:value-of select="$vtrans"/> )
  					<xsl:choose>
		  				<xsl:when test="DEPTYPE &lt;= 3">
		  					AND
					  				PACKAGE_VERSIONS.INSTALLED=FALSE
		  				</xsl:when>
		  				<xsl:when test="DEPTYPE &gt; 3">
		  					AND
		  						PACKAGE_VERSIONS.INSTALLED=TRUE
		  				</xsl:when>
		  			</xsl:choose>
  				</xsl:when>
  				<xsl:when test="EQUALITY=4">
  					PACKAGE_VERSIONS.VERSION &gt;=  ( <xsl:value-of select="$vtrans"/> )
  					<!-- 1 depends, 2 suggests, 3 recommends, 4 confilcts, 5 replaces -->
		  			<xsl:choose>
		  				<xsl:when test="DEPTYPE &lt;= 3">
		  					AND
					  				PACKAGE_VERSIONS.INSTALLED=FALSE
		  					AND
		  						(
			  						SELECT PACKAGE_VERSIONS.ID
			  						FROM 
			  						PACKAGES, PACKAGE_VERSIONS
			  						WHERE
			  						PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
						  			AND
						  			PACKAGES.NAME='<xsl:value-of select="NAME"/>'
						  			AND
						  			PACKAGE_VERSIONS.VERSION &gt;=  ( <xsl:value-of select="$vtrans"/> )
						  			AND
						  			PACKAGE_VERSIONS.INSTALLED=TRUE
					  			) IS NULL
		  				</xsl:when>
		  				<xsl:when test="DEPTYPE &gt; 3">
		  					AND
		  						PACKAGE_VERSIONS.INSTALLED=TRUE
		  				</xsl:when>
		  			</xsl:choose>
  				</xsl:when>
  				<xsl:when test="EQUALITY=5">
  					PACKAGE_VERSIONS.VERSION &gt;  ( <xsl:value-of select="$vtrans"/> )
  					<xsl:choose>
		  				<xsl:when test="DEPTYPE &lt;= 3">
		  					AND
					  				PACKAGE_VERSIONS.INSTALLED=FALSE
		  					AND
		  						(
			  						SELECT PACKAGE_VERSIONS.ID
			  						FROM 
			  						PACKAGES, PACKAGE_VERSIONS
			  						WHERE
			  						PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
						  			AND
						  			PACKAGES.NAME='<xsl:value-of select="NAME"/>'
						  			AND
						  			PACKAGE_VERSIONS.VERSION &gt;  ( <xsl:value-of select="$vtrans"/> )
						  			AND
						  			PACKAGE_VERSIONS.INSTALLED=TRUE
					  			) IS NULL
		  				</xsl:when>
		  				<xsl:when test="DEPTYPE &gt; 3">
		  					AND
		  						PACKAGE_VERSIONS.INSTALLED=TRUE
		  				</xsl:when>
		  			</xsl:choose>
  				</xsl:when>
  			</xsl:choose>
  			;
  </sql>
  </xsl:template>

</xsl:stylesheet> 
