<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrl="http://netkernel.org/xrl" xmlns:nk="http://netkernel.org">
  <xsl:output method="xml"/>

	<xsl:param name="type" nk:class="java.lang.String"/>
	<xsl:param name="repocollectionid" nk:class="java.lang.String"/>
	<xsl:param name="repocollectionsetid" nk:class="java.lang.String"/>

  <xsl:template match="/packages">
  <batch>
  	<sql>BEGIN</sql>
  	<xsl:apply-templates select="package"/>
  		<!--
  		<sql>
			UPDATE PACKAGE_VERSIONS SET INSTALLED=FALSE WHERE INSTALLED IS NULL;
		</sql>
		
		<sql>
			UPDATE PACKAGE_VERSIONS SET HASUPDATE=TRUE
			WHERE
			HASUPDATE IS NULL
			AND
			PACKAGE_VERSIONS.INSTALLED=TRUE
			AND
			PACKAGE_VERSIONS.PACKAGEID
			IN
			(	SELECT
				PACKAGEID
				FROM
				PACKAGE_VERSIONS
				WHERE
				ID
				IN
				(	SELECT
						ID
					FROM
					(
						SELECT A.* FROM
							PACKAGE_VERSIONS AS A
							JOIN
							(	SELECT		
									PACKAGEID,
									MAX(PACKAGE_VERSIONS.VERSION) as VERSION
									FROM 
										PACKAGE_VERSIONS
									GROUP BY PACKAGEID
							)
							AS B
							ON A.PACKAGEID=B.PACKAGEID AND A.VERSION=B.VERSION
					)
				)
				AND
				INSTALLED=FALSE
				AND
				TYPE=2
			)
			;
		</sql>
		<sql>
			UPDATE PACKAGE_VERSIONS SET HASSECURITY=TRUE
			WHERE
			HASSECURITY IS NULL
			AND
			PACKAGE_VERSIONS.INSTALLED=TRUE
			AND
			PACKAGE_VERSIONS.PACKAGEID
			IN
			(	SELECT
				PACKAGEID
				FROM
				PACKAGE_VERSIONS
				WHERE
				ID
				IN
				(	SELECT
						ID
					FROM
					(
						SELECT A.* FROM
							PACKAGE_VERSIONS AS A
							JOIN
							(	SELECT		
									PACKAGEID,
									MAX(PACKAGE_VERSIONS.VERSION) as VERSION
									FROM 
										PACKAGE_VERSIONS
									GROUP BY PACKAGEID
							)
							AS B
							ON A.PACKAGEID=B.PACKAGEID AND A.VERSION=B.VERSION
					)
				)
				AND
				INSTALLED=FALSE
				AND
				TYPE=3
			)
			;
		</sql>
		-->
  	<sql>COMMIT</sql>
  </batch>
  </xsl:template>

	<xsl:template match="package">
		<sql>
			MERGE INTO PACKAGES(
                REPOCOLLECTIONSETID,
				NAME,
				DESCR,
				MAINTAINER,
				RUNLEVEL,
				SECTION,
				WWW,
				LICENSE
			)
			KEY (REPOCOLLECTIONSETID, NAME)
			VALUES
			(
			<xsl:value-of select="$repocollectionsetid"/>,
			'<xsl:value-of select="name"/>',
			'<xsl:value-of select="packagedescr"/>',
			'<xsl:value-of select="maintainer"/>',
			<xsl:value-of select="runlevel"/>,
			'<xsl:value-of select="section"/>',
			'<xsl:value-of select="www"/>',
			'<xsl:value-of select="license"/>'
			)
			;
		</sql>
		<sql>
			MERGE INTO PACKAGE_VERSIONS(
				PACKAGEID,
				VERSION,
				SIZE,
				INSTALLED,
				TYPE,
				FILENAME,
				FILEPATH,
				LOCALSRC,
				DESCR,
				SIGNATURE,
				MD5,
				SHA256
			)
			KEY (PACKAGEID, VERSION)
			VALUES
			(
				(	SELECT ID FROM PACKAGES
						WHERE
							NAME='<xsl:value-of select="name"/>'
							AND
							REPOCOLLECTIONSETID=<xsl:value-of select="$repocollectionsetid"/>
				), 	
				 ( <xsl:value-of select="translate(version, '.', ',')"/> ),
				 <xsl:value-of select="size"/>,
				(	 	SELECT INSTALLED FROM
					 	PACKAGES, PACKAGE_VERSIONS
					 	WHERE
					 	PACKAGES.NAME='<xsl:value-of select="name"/>'
					 	AND
					 	PACKAGES.REPOCOLLECTIONSETID=<xsl:value-of select="$repocollectionsetid"/>
					 	AND
					 	PACKAGES.ID=PACKAGE_VERSIONS.PACKAGEID
						AND
						PACKAGE_VERSIONS.VERSION=( <xsl:value-of select="translate(version, '.', ',')"/> )
				  ),
				 <xsl:choose>
				 	<xsl:when test="$type='base'">1</xsl:when>
				 	<xsl:when test="$type='update'">2</xsl:when>
				 	<xsl:when test="$type='security'">3</xsl:when>
				 </xsl:choose>,
				 '<xsl:value-of select="filename"/>',
				 '<xsl:value-of select="filepath"/>',
				 NULL,
				 '<xsl:value-of select="versiondescr"/>',
				 '<xsl:value-of select="trust/signature"/>',
				 '<xsl:value-of select="trust/md5"/>',
				 '<xsl:value-of select="trust/sha256"/>'
				)
				;
		</sql>
		
		
		<xsl:if test="dependencies/dependency">
		<sql>
				DELETE FROM PACKAGE_VERSION_DEPENDS
				WHERE PACKAGEVID=
					(	SELECT PACKAGE_VERSIONS.ID
						FROM	
							PACKAGE_VERSIONS, PACKAGES
							WHERE
								PACKAGE_VERSIONS.PACKAGEID=PACKAGES.ID
								AND
								PACKAGE_VERSIONS.VERSION=( <xsl:value-of select="translate(version, '.', ',')"/> )
								AND
								PACKAGES.NAME='<xsl:value-of select="name"/>'
					)
				;
			</sql>
		</xsl:if>
		
		<xsl:for-each select="dependencies/dependency">
			<sql>
				INSERT INTO PACKAGE_VERSION_DEPENDS VALUES
				(	NULL,
					( SELECT PACKAGE_VERSIONS.ID
						FROM	
							PACKAGE_VERSIONS, PACKAGES
							WHERE
								PACKAGE_VERSIONS.PACKAGEID=PACKAGES.ID
								AND
								PACKAGE_VERSIONS.VERSION=( <xsl:value-of select="translate(../../version, '.', ',')"/> )
								AND
								PACKAGES.NAME='<xsl:value-of select="../../name"/>'
						),
						'<xsl:value-of select="name"/>',
						<xsl:choose>
							<xsl:when test="deptype='depends'">1</xsl:when>
							<xsl:when test="deptype='suggests'">2</xsl:when>
							<xsl:when test="deptype='recommends'">3</xsl:when>
							<xsl:when test="deptype='conflicts'">4</xsl:when>
							<xsl:when test="deptype='replaces'">5</xsl:when>
						</xsl:choose>,
						<xsl:choose>
							<xsl:when test="equality='lt'">1</xsl:when>
							<xsl:when test="equality='lte'">2</xsl:when>
							<xsl:when test="equality='e'">3</xsl:when>
							<xsl:when test="equality='gte'">4</xsl:when>
							<xsl:when test="equality='gt'">5</xsl:when>
						</xsl:choose>,
						( <xsl:value-of select="translate(version, '.', ',')"/> )
					)
					;
			</sql>
		</xsl:for-each>
		
	</xsl:template>

</xsl:stylesheet> 
