package org.netkernel.packge.endpoint;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.net.URI;
import java.util.zip.ZipOutputStream;

import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.INKFResponse;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IHDSNodeList;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.layer0.representation.impl.HDSFactory;
import org.netkernel.layer0.util.XMLUtils;
import org.netkernel.layer1.representation.FileRepresentation;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.netkernel.packge.util.ZipUtils;
import org.w3c.dom.Document;

public class PackageAccessor extends StandardAccessorImpl
{
	private static final String BASEPATH="modules/";
	@Override
	public void onSource(INKFRequestContext context) throws Exception
	{
		IHDSNode opd=context.source("arg:operand", IHDSNode.class);
		
		File zip=File.createTempFile("nk-package"+System.currentTimeMillis(),".jar");
		ZipOutputStream zos = new ZipOutputStream(new FileOutputStream(zip)); 
		
		HDSBuilder b=new HDSBuilder();
		b.pushNode("manifest");
		b.addNode("name" , opd.getFirstValue("package/uri"));
		b.importNode(opd.getFirstNode("package/description"));
		b.importNode(opd.getFirstNode("package/version"));
		
		IHDSNodeList nl=opd.getNodes("package/module");
		for(int i=0; i<nl.size(); i++)
		{	IHDSNode n=nl.get(i);
			URI uri=URI.create((String)n.getFirstValue("source"));
			File file=new File(uri);
			String filename=file.getName();
			if(file.isDirectory())
			{	filename+="/";
				File zip2=File.createTempFile(file.getName(),".jar");
				ZipOutputStream zos2 = new ZipOutputStream(new FileOutputStream(zip2));
				ZipUtils.zipDir(file,zos2,null, "");
				zos2.close();
				ZipUtils.zipFile(zip2,zos, BASEPATH);
				filename=zip2.getName();
				zip2.delete();
			}
			else
			{	ZipUtils.zipFile(file,zos, BASEPATH);
			}
			b.pushNode("module");
				b.importNode(n.getFirstNode("uri"));
				b.importNode(n.getFirstNode("version"));
				b.importNode(n.getFirstNode("runlevel"));
				IHDSNode fulcrum=n.getFirstNode("fulcrum");
				if(fulcrum!=null)
				{	b.importNode(fulcrum);
				}
				b.addNode("source", BASEPATH+filename);
				boolean expand;
				if(n.getFirstNode("expand")!=null)
				{	expand=true;					
				}
				else
				{	expand=file.isDirectory();					
				}
				b.addNode("expand", expand);
				//b.importNode(n.getFirstNode("dependencies"));
			b.popNode();
		}
		b.popNode();
		
		Document manifestDoc=HDSFactory.toDOM(b.getRoot());
		ZipUtils.zipVirtual("manifest.xml", new ByteArrayInputStream(XMLUtils.toXML(manifestDoc.getDocumentElement(), true, false).getBytes()),zos);
		
		//Create module.xml
		INKFRequest req=context.createRequest("active:freemarker");
		req.addArgument("operator","res:/org/netkernel/packge/template/module-template.xml");
		req.addArgumentByValue("args", opd);
		req.setRepresentationClass(String.class);
		String moduledefn=(String)context.issueRequest(req);
		ZipUtils.zipVirtual("module.xml", new ByteArrayInputStream(moduledefn.getBytes()),zos);
		
		//zos.finish();
		
		//Sign Module
		String keystoreURI=(String)opd.getFirstValue("package/keystoreURI");
		if(keystoreURI!=null && keystoreURI.length()>0)
		{	context.setCWU(null);
			req=context.createRequest("active:pkiSignModule");
			req.addArgument("operand", zip.toURI().toString());
			req.addArgument("keystore", keystoreURI);
			req.addArgumentByValue("keystorePassword", (String)opd.getFirstValue("package/keystorePassword"));
			req.addArgument("keyID", (String)opd.getFirstValue("package/keyAlias"));
			req.addArgumentByValue("keyPassword", (String)opd.getFirstValue("package/keyPassword"));
			req.setRepresentationClass(String.class);
			String sig=(String)context.issueRequest(req);
			ZipUtils.zipVirtual("module.signature", new ByteArrayInputStream(sig.getBytes()),zos);
		}

		zos.close();
		
		
		FileRepresentation rep=new FileRepresentation(zip);
		INKFResponse response=context.createResponseFrom(rep);
		response.setMimeType("application/zip");
	}
}
